.. _talairach_atlas:

Talairach atlas
===============

Access
------
See :func:`nilearn.datasets.fetch_atlas_talairach`.

Notes
-----

For more information,
see :footcite:t:`talairach_atlas`,
:footcite:t:`Lancaster2000`,
and :footcite:t:`Lancaster1997`.

Content
-------
    :'maps': 3D Nifti image, values are integers corresponding to indices in the
             list of labels.

    :'labels': Annotations ({})

References
----------

.. footbibliography::


License
-------
unknown
